Please un peu d'aide :linux

est ce que GNU/LINUX est une distribution ou un systheme unix?
et la version 2 1 33 de linux est ce qu'elle est instable ou de developement?est la commande 'apropos man ' qu'est ce qu'elle affiche?

et pour le shell:(qu'elle est la bonne reponse entre ces choix,avec possibilité d'avoire plusieurs choix) :
assure le dialogue homme machine
joue le role de language de programmation
gere les connexion au reseaux
gere les fenetres

5 réponses

  1. Bonjour

    GNU/Linux est un noyau entouré d'autres logiciels libre.
    Le noyau possède une numérotation et les distributions aussi, en général;
    Le shell est la pour que l'homme puisse discuter avec la machine, il interprete;
    heu ! man à propos
    0
    1. Contributeur
      Bonjour,

      Un peu d'aide ici :
      http://www.guidelinux.org/

      le man est en qq sorte un "livre" de documentation sur les commandes
      par exemple, si tu tapes
      man cp
      tu obtiendras plein d'informations sur la manière d'utiliser la commande cp (qui veut dire copier)

      Bonne découverte.
      0
      1. bonjour
        mon probleme c'est pas man
        mon probleme c'est apropos man
        et en + j'ai un probleme dans mon ordinateur c'est jour et je ne peux pas utiliser unix c'est pour ça que je pose ces question sur ce forum...
        0
    2. Contributeur
      Salut,

      et si tu tape man apropos, tu devrais obtenir ceci :

      APROPOS(1) Manual pager utils APROPOS(1)

      NAME
      apropos - search the manual page names and descriptions

      SYNOPSIS
      apropos [-dhV] [-e|-w|-r] [-s section] [-m system[,...]] [-M path] [-C
      file] keyword ...

      DESCRIPTION
      Each manual page has a short description available within it. apropos
      searches the descriptions for instances of keyword.

      keyword is usually a regular expression, as if (-r) was used, or may
      contain wildcards (-w), or match the exact keyword (-e). Using these
      options, it may be necessary to quote the keyword or escape (\) the
      special characters to stop the shell from interpreting them.

      The standard matching rules allow matches to be made against the page
      name and word boundaries in the description.

      OPTIONS
      -d, --debug
      Print debugging information.

      -v, --verbose
      Print verbose warning messages.

      -r, --regex
      Interpret each keyword as a regular expression. This is the
      default behaviour. Each keyword will be matched against the
      page names and the descriptions independently. It can match any
      part of either. The match is not limited to word boundaries.

      -w, --wildcard
      Interpret each keyword as a pattern containing shell style wild-
      cards. Each keyword will be matched against the page names and
      the descriptions independently. If --exact is also used, a
      match will only be found if an expanded keyword matches an
      entire description or page name. Otherwise the keyword is also
      allowed to match on word boundaries in the description.

      -e, --exact
      Each keyword will be exactly matched against the page names and
      the descriptions.

      -s section, --section section
      Search only the given manual section. If section is a simple
      section, for example "3", then the displayed list of descrip-
      tions will include pages in sections "3", "3perl", "3x", and so
      on; while if section has an extension, for example "3perl", then
      the list will only include pages in that exact part of the man-
      ual section.

      -m system[,...], --systems=system[,...]
      If this system has access to other operating system's manual
      page descriptions, they can be searched using this option. To
      search NewOS's manual page descriptions, use the option -m
      NewOS.

      The system specified can be a combination of comma-delimited
      operating system names. To include a search of the native oper-
      ating system's whatis descriptions, include the system name man
      in the argument string. This option will override the $SYSTEM
      environment variable.

      -M path, --manpath=path
      Specify an alternate set of colon-delimited manual page hierar-
      chies to search. By default, apropos uses the $MANPATH environ-
      ment variable, unless it is empty or unset, in which case it
      will determine an appropriate manpath based on your $PATH envi-
      ronment variable. This option overrides the contents of $MAN-
      PATH.

      -C file, --config-file=file
      Use this user configuration file rather than the default of
      ~/.manpath.

      -h, --help
      Print a help message and exit.

      -V, --version
      Display version information.

      EXIT STATUS
      0 Successful program execution.

      1 Usage, syntax or configuration file error.

      2 Operational error.

      16 Nothing was found that matched the criteria specified.

      ENVIRONMENT
      SYSTEM If $SYSTEM is set, it will have the same effect as if it had
      been specified as the argument to the -m option.

      MANPATH
      If $MANPATH is set, its value is interpreted as the colon-delim-
      ited manual page hierarchy search path to use.

      POSIXLY_CORRECT
      If $POSIXLY_CORRECT is set, even to a null value, the default
      apropos search will be as an extended regex (-r) . Nowadays,
      this is the default behaviour anyway.

      FILES
      /usr/share/man/index.(bt|db|dir|pag)
      A traditional global index database cache.

      /var/cache/man/index.(bt|db|dir|pag)
      An alternate or FHS compliant global index database cache.

      /usr/share/man/.../whatis
      A traditional whatis text database.

      SEE ALSO
      whatis(1), man(1).

      AUTHOR
      Wilf. (G.Wilford@ee.surrey.ac.uk).
      Fabrizio Polacco (fpolacco@debian.org).

      2.4.3 2005-07-03 APROPOS(1)

      donc c'est aussi un outil pour chercher les page de manuel.

      Par contre je n'ai vu sur aucun de tes posts une descritpion d'un problème.

      Renisaac
      0
      1. non!!!!!
        j'ai dit apropos man et pas man apropos
        0
    3. Contributeur
      re-

      entre nous, ma réponse contient toutes les infos que tu a demandé!!! et si tu parle pas anglais, ce serai bien de le préciser.

      apropos te donne une liste de page de manuel qui contiennent un mot (le mot man par exemple, ou toto, ou schlimbick si tu veux). Et si je te donne la page de manuel, c'est pour te permettre de tirer toutes les possibilité de la fonction apropos. Donc OUI, cede et moi avons répondu à la question que tu a posée. Si ce n'est pas ça que tu veux savoir, explique mieux ce que tu veux savoir.

      Au fait, qu'est ce qui t'empêche de tester cette commande chez toi?

      Renisaac
      0
      1. donc exactement apropos man affiche
        la liste de toute la documentation disponible
        ou bien
        la liste des references à man dans la documentation en ligne

        ce qui m'en peche d'utiliser linux c'est que j'ai un probleme dans mon PC en ce moment....
        0
    4. Contributeur
       Each manual page has a short description available within it. apropos
      searches the descriptions for instances of keyword. 


      donc liste les page man dont les mots cléf contiennent le mot cherché (man dans ton cas).

      Renisaac
      0